"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const Button_1 = require("../Button/Button");
const classNames_1 = require("../../utils/classNames");
const calculate_popup_position_1 = __importDefault(require("./helpers/calculate-popup-position"));
const react_fontawesome_1 = require("@fortawesome/react-fontawesome");
const faXmark_1 = require("@fortawesome/pro-regular-svg-icons/faXmark");
const Popup = ({ title, description, children, open = false, setOpen, minWidth = 260, minHeight = 0, onCancel, onConfirm, cancelButtonText, confirmButtonText, loading = false, direction = 'right', parentRef, withCloseButton = true, }) => {
    const getBaseClasses = (direction, parentRef) => {
        switch (direction) {
            case 'left':
                return ['popup', 'popup-left'];
            case 'right':
                return ['popup', 'popup-right'];
            case 'top':
                return ['popup', 'popup-top'];
            case 'bottom':
                return ['popup', 'popup-bottom'];
            case 'auto':
                if (!(parentRef === null || parentRef === void 0 ? void 0 : parentRef.current))
                    return ['popup', 'popup-right'];
                const direction = (0, calculate_popup_position_1.default)(parentRef === null || parentRef === void 0 ? void 0 : parentRef.current);
                return ['popup', `popup-${direction}`];
            default:
                return ['popup', 'popup-right'];
        }
    };
    const baseClasses = (0, react_1.useMemo)(() => {
        const result = getBaseClasses(direction, parentRef);
        return result;
    }, [direction, parentRef]);
    const [popupClasses, setPopupClasses] = (0, react_1.useState)([...baseClasses]);
    const [backdropClasses, setBackdropClasses] = (0, react_1.useState)([
        'backdrop',
    ]);
    const togglePopup = async () => {
        if (open) {
            setPopupClasses([...baseClasses, 'popup-fadeout']);
            setBackdropClasses(['popup-backdrop', 'popup-fadeout']);
            await new Promise((resolve) => setTimeout(resolve, 500));
            setOpen(false);
            setPopupClasses([...baseClasses]);
            setBackdropClasses(['popup-backdrop']);
        }
        else {
            setOpen(true);
        }
    };
    const applyFadeIn = (0, react_1.useCallback)(async () => {
        setPopupClasses([...baseClasses, 'popup-fadein']);
        setBackdropClasses(['popup-backdrop', 'popup-fadein']);
    }, [baseClasses]);
    (0, react_1.useEffect)(() => {
        setPopupClasses([...baseClasses]);
        if (open) {
            void applyFadeIn();
        }
    }, [open, baseClasses, applyFadeIn]);
    console.log('testo besto');
    const onConfirmClick = async () => {
        if (!onConfirm) {
            void togglePopup();
            return;
        }
        try {
            await onConfirm();
            void togglePopup();
        }
        catch (error) {
            console.error(error);
        }
    };
    const onCancelClick = async () => {
        if (!onCancel) {
            void togglePopup();
            return;
        }
        try {
            await onCancel();
        }
        catch (error) {
            console.error(error);
        }
        finally {
            void togglePopup();
        }
        return;
    };
    (0, react_1.useEffect)(() => {
        const handleEsc = (event) => {
            if (!open)
                return;
            if (event.key === 'Escape') {
                void togglePopup();
            }
        };
        window.addEventListener('keydown', handleEsc);
        return () => {
            window.removeEventListener('keydown', handleEsc);
        };
    });
    if (!open)
        return null;
    return ((0, jsx_runtime_1.jsxs)("div", { className: "popup-container", children: [(0, jsx_runtime_1.jsx)("div", { className: (0, classNames_1.classNames)(...backdropClasses), onClick: () => void togglePopup() }), (0, jsx_runtime_1.jsxs)("div", { className: (0, classNames_1.classNames)(...popupClasses), style: { minWidth, minHeight }, children: [title && ((0, jsx_runtime_1.jsxs)("div", { className: 'popup-header', children: [(0, jsx_runtime_1.jsx)("h4", { className: 'popup-title', children: title }), withCloseButton && ((0, jsx_runtime_1.jsx)(Button_1.Button, { type: "ghost", color: "primary", className: "popup-close", children: (0, jsx_runtime_1.jsx)(react_fontawesome_1.FontAwesomeIcon, { icon: faXmark_1.faXmark, onClick: togglePopup, color: "black" }) }))] })), (0, jsx_runtime_1.jsxs)("div", { className: 'popup-content', children: [description && (0, jsx_runtime_1.jsx)("p", { children: description }), children] }), (0, jsx_runtime_1.jsxs)("div", { className: 'popup-footer', children: [cancelButtonText && ((0, jsx_runtime_1.jsx)(Button_1.Button, { "data-testid": "cancelButton", disabled: loading, color: "secondary", onClick: () => void onCancelClick(), label: cancelButtonText })), confirmButtonText && ((0, jsx_runtime_1.jsx)(Button_1.Button, { "data-testid": "confirmButton", disabled: loading, onClick: () => void onConfirmClick(), label: confirmButtonText }))] })] })] }));
};
exports.default = Popup;
//# sourceMappingURL=Popup.js.map