"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.classNames = void 0;
/**
 * Construct a className string from a list of class name values,
 * filtering out any falsy values.
 *
 * For example:
 *
 * ```
 * classNames('one', false, 'two', undefined);
 * // Returns: 'one two'
 * ```
 *
 * This also makes it simple to apply conditional class names:
 *
 * ```
 * classNames('thing', active && 'active');
 * // Returns 'thing active' if active is truthy, or 'thing' otherwise.
 * ```
 *
 * @param classList The class names to concatenate.
 */
function classNames(...classList) {
    return classList.filter((c) => !!c).join(' ');
}
exports.classNames = classNames;
//# sourceMappingURL=classNames.js.map